# EvInventory

## Reducing Stock Levels

If building an application with custom inventories integration then you can use the following code as a basis to trigger the reduction of inventory stock levels.

	if (CakePlugin::loaded('EvInventory')) {
		// dispatch event to lower stock levels
		$this->getEventManager()->dispatch(
			new CakeEvent('EvInventory.Inventory.reduce', $this, array(
				'model' => $item['model'],
				'model_id' => $item['model_id'],
				'quantity' => $item['quantity']
			))
		);
	}

If called from a component, change the line `$this->getEventManager()->dispatch` to `$this->_controller->getEventManager()->dispatch`.

The event always requires the 3 parameters above. If any are missing in any combination the event will fail to run correctly.

## Checking if Stock Exists

If building a custom integration with inventories and you need to check there is enough stock to fulfil a request, you can use the code below as example.

	$Model = EvClassRegistry::init($item['BasketItem']['model']); // e.g.  EvShop.Variant
	if (CakePlugin::loaded('EvInventory') && $Model->hasBehavior('EvInventory.Inventories')) {
		App::uses('InventoryLib', 'EvInventory.Lib');

		if (
			InventoryLib::hasEnoughStock(
				$Model->readForEdit($item['BasketItem']['model_id']),
				$item['BasketItem']['quantity']
			)
		) {
			return true;
		}
	}

## Events

### EvInventory.Behavior.Inventory.saved

Called by the behavior when the inventory items are updated by the product (e.g. when stock levels are updated)

The `subject` for the event is the Model that the behaviour is attached to.

#### Parameters

* `id` - The model item id numbers inventory we just updated.
